==> card_input_field-0.2.1.tar.gz: lib/card_input_field.dart <==
import 'dart:async';
import 'dart:ui';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class CardInputField extends StatefulWidget {
  List<TextEditingController> controllers = [
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
  ];

  @override
  _CardInputFieldState createState() => _CardInputFieldState();
}

class _CardInputFieldState extends State<CardInputField> {
  List<FocusNode> focusNodes = [
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
  ];

  Widget input(
      FocusNode? before,
      FocusNode self,
      FocusNode? next,
      TextEditingController controller,
      ) =>
      Padding(
        padding: const EdgeInsets.symmetric(horizontal: 3.0),
        child: SizedBox(
          width: 12.0,
          height: 35.0,
          child: TextField(
            controller: controller,
            keyboardType: TextInputType.number,
            inputFormatters: <TextInputFormatter>[
              FilteringTextInputFormatter.digitsOnly,
            ],
            maxLength: 1,
            showCursor: false,
            style: TextStyle(fontSize: 14.0),
            decoration: InputDecoration(
              counterText: '',
              contentPadding: const EdgeInsets.only(top: -10.0),
            ),
            // textInputAction: TextInputAction.next,
            focusNode: self,
            // onSubmitted: (String value) {
            //   self.unfocus();
            //   if (next != null) FocusScope.of(context).requestFocus(next);
            // },
            onChanged: (val) {
              if (val != '' && next != null) {
                self.unfocus();
                FocusScope.of(context).requestFocus(next);
              } else if (before != null) {
                self.unfocus();
                FocusScope.of(context).requestFocus(before);
              }
            },
          ),
        ),
      );

  Widget box(
      FocusNode? before1,
      FocusNode self1,
      FocusNode next1,
      FocusNode self2,
      FocusNode next2,
      FocusNode self3,
      FocusNode next3,
      FocusNode self4,
      FocusNode? next4,
      TextEditingController controller1,
      TextEditingController controller2,
      TextEditingController controller3,
      TextEditingController controller4,
      ) =>
      Container(
        decoration: BoxDecoration(
          color: Theme.of(context).backgroundColor,
          borderRadius: BorderRadius.circular(4.0),
        ),
        padding: const EdgeInsets.only(bottom: 8.0),
        child: Row(
          mainAxisSize: MainAxisSize.min,
          children: [
            input(before1, self1, next1, controller1),
            input(self1, self2, next2, controller2),
            input(self2, self3, next3, controller3),
            input(self3, self4, next4, controller4),
          ],
        ),
      );
	  
  @override
  void initState() {
    super.initState();
    Timer(Duration(milliseconds: 200), () {
      for (int i = 0; i < widget.controllers.length; i++)
        if (widget.controllers[i].text == '') {
          focusNodes[i].requestFocus();
          break;
        }
    });
  }

  @override
  Widget build(BuildContext context) {
    return Directionality(
      textDirection: TextDirection.ltr,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          box(
            null,
            focusNodes[0],
            focusNodes[1],
            focusNodes[1],
            focusNodes[2],
            focusNodes[2],
            focusNodes[3],
            focusNodes[3],
            focusNodes[4],
            widget.controllers[0],
            widget.controllers[1],
            widget.controllers[2],
            widget.controllers[3],
          ),
          box(
            focusNodes[3],
            focusNodes[4],
            focusNodes[5],
            focusNodes[5],
            focusNodes[6],
            focusNodes[6],
            focusNodes[7],
            focusNodes[7],
            focusNodes[8],
            widget.controllers[4],
            widget.controllers[5],
            widget.controllers[6],
            widget.controllers[7],
          ),
          box(
            focusNodes[7],
            focusNodes[8],
            focusNodes[9],
            focusNodes[9],
            focusNodes[10],
            focusNodes[10],
            focusNodes[11],
            focusNodes[11],
            focusNodes[12],
            widget.controllers[8],
            widget.controllers[9],
            widget.controllers[10],
            widget.controllers[11],
          ),
          box(
            focusNodes[11],
            focusNodes[12],
            focusNodes[13],
            focusNodes[13],
            focusNodes[14],
            focusNodes[14],
            focusNodes[15],
            focusNodes[15],
            null,
            widget.controllers[12],
            widget.controllers[13],
            widget.controllers[14],
            widget.controllers[15],
          ),
        ],
      ),
    );
  }

  @override
  void dispose() {
    focusNodes.forEach((element) {
      element.dispose();
    });
    super.dispose();
  }
}

==> card_input_field-1.0.0.tar.gz: lib/card_input_field.dart <==
import 'dart:async';
import 'dart:ui';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class CardInputField extends StatefulWidget {
  List<TextEditingController> controllers = [
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
    TextEditingController(),
  ];

  @override
  _CardInputFieldState createState() => _CardInputFieldState();
}

class _CardInputFieldState extends State<CardInputField> {
  List<FocusNode> focusNodes = [
    FocusNode(),
    FocusNode(),
    FocusNode(),
    FocusNode(),
  ];

  Widget input(
      FocusNode? before,
      FocusNode self,
      FocusNode? next,
      TextEditingController controller,
      ) =>
      Padding(
        padding: const EdgeInsets.symmetric(horizontal: 3.0),
        child: SizedBox(
          width: 70.0,
          height: 35.0,
          child: TextField(
            controller: controller,
            keyboardType: TextInputType.number,
            inputFormatters: <TextInputFormatter>[
              FilteringTextInputFormatter.digitsOnly,
            ],
            maxLength: 4,
            style: const TextStyle(fontSize: 14.0, letterSpacing: 3.0),
            textAlign: TextAlign.center,
            decoration: InputDecoration(
              counterText: '',
              contentPadding: const EdgeInsets.only(top: -10.0),
            ),
            // textInputAction: TextInputAction.next,
            focusNode: self,
            // onSubmitted: (String value) {
            //   self.unfocus();
            //   if (next != null) FocusScope.of(context).requestFocus(next);
            // },
            onChanged: (val) {
              if (val.length == 4 && next != null) {
                self.unfocus();
                FocusScope.of(context).requestFocus(next);
              } else if (before != null && val.length == 0) {
                self.unfocus();
                FocusScope.of(context).requestFocus(before);
              }
            },
          ),
        ),
      );

  Widget box(
      FocusNode? before,
      FocusNode self,
      FocusNode? next,
      TextEditingController controller,
      ) =>
      Container(
        decoration: BoxDecoration(
          color: Theme.of(context).backgroundColor,
          borderRadius: BorderRadius.circular(4.0),
        ),
        padding: const EdgeInsets.only(bottom: 8.0),
        child: input(before, self, next, controller),
      );
	  
  @override
  void initState() {
    super.initState();
    Timer(Duration(milliseconds: 200), () {
      for (int i = 0; i < widget.controllers.length; i++)
        if (widget.controllers[i].text.length < 4) {
          focusNodes[i].requestFocus();
          break;
        }
    });
  }

  @override
  Widget build(BuildContext context) {
    return Directionality(
      textDirection: TextDirection.ltr,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          box(null, focusNodes[0], focusNodes[1], widget.controllers[0]),
          box(
            focusNodes[0],
            focusNodes[1],
            focusNodes[2],
            widget.controllers[1],
          ),
          box(
            focusNodes[1],
            focusNodes[2],
            focusNodes[3],
            widget.controllers[2],
          ),
          box(focusNodes[2], focusNodes[3], null, widget.controllers[3]),
        ],
      ),
    );
  }

  @override
  void dispose() {
    focusNodes.forEach((element) {
      element.dispose();
    });
    super.dispose();
  }
}
